@@ -25,6 +25,8 @@
 #'  Default value is 'contrast'.
 #' @param stat.name Character. Indicates the name of the variable that report the statistics in report.quanti function.
 #' Default = "Statistics"
+#' @param regrouped Logical. used to indicate if the desc object regroup several desc objects (see \code{\link{regroup.desc}} )
+#' @param rbind.label Character. The name of the label in case several desc objects are regrouped
 #' 
 #' 
 #' @description
@@ -55,7 +57,8 @@
 desc=function(output=NULL,total=NULL,nbcol=NULL,y=NULL,x1=NULL,x2=NULL,
 		at.row=NULL,
 		subjid=NULL,type.desc=NULL,type=NULL,y.label=NULL,type.mod=NULL,
-		raw.output=NULL,contrast=NULL,contrast.name=NULL,stat.name=NULL)
+		raw.output=NULL,contrast=NULL,contrast.name=NULL,stat.name=NULL,
+		regrouped=F,rbind.label=NULL)
 {
 	
 	
@@ -63,7 +66,8 @@ desc=function(output=NULL,total=NULL,nbcol=NULL,y=NULL,x1=NULL,x2=NULL,
 			at.row=at.row,
 			subjid=subjid,type.desc=type.desc,type=type,y.label=y.label,
 			type.mod=type.mod,raw.output=raw.output,contrast=contrast,
-			contrast.name=contrast.name,stat.name=stat.name)
+			contrast.name=contrast.name,stat.name=stat.name,regrouped=regrouped,
+			rbind.label=rbind.label)
 	
 	class(l)="desc"
 	
